contexttools.KeySignatureMark
=============================

.. abjad-lineage:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark

.. autoclass:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.attach
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.detach
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.effective_context
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.lilypond_format
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.mode
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.name
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.start_component
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.storage_format
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.target_context
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.tonic
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__call__
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__copy__
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__eq__
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__ne__
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__repr__
      ~abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__str__

Bases
-----

- :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

- :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.effective_context
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.name
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.start_component
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.storage_format
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.target_context
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.mode
   :noindex:

.. autoattribute:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.tonic
   :noindex:

Methods
-------

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.attach
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.detach
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__call__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__copy__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__eq__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__ne__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__repr__
   :noindex:

.. automethod:: abjad.tools.contexttools.KeySignatureMark.KeySignatureMark.KeySignatureMark.__str__
   :noindex:
